@@ -21,13 +21,14 @@
 #include "alarmcalendar.h"
 
 #include "kalarm.h"
-#include "filedialog.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
-#include "messagebox.h"
 #include "preferences.h"
+#include "resources/datamodel.h"
 #include "resources/resources.h"
+#include "lib/filedialog.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
 #include <KCalendarCore/MemoryCalendar>
@@ -37,21 +38,21 @@
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <kfileitem.h>
+#include <KFileItem>
 #include <KSharedConfig>
+#include <kio_version.h>
 
 #include <QTemporaryFile>
 #include <QStandardPaths>
 #include <QFileDialog>
 
-using namespace Akonadi;
 using namespace KCalendarCore;
 using namespace KAlarmCal;
 
 static KACalendar::Compat fix(const KCalendarCore::FileStorage::Ptr&);
 
 static const QString displayCalendarName = QStringLiteral("displaying.ics");
-static const Collection::Id DISPLAY_COL_ID = -1;   // resource ID used for displaying calendar
+static const ResourceId DISPLAY_COL_ID = -1;   // resource ID used for displaying calendar
 
 AlarmCalendar* AlarmCalendar::mResourcesCalendar = nullptr;
 AlarmCalendar* AlarmCalendar::mDisplayCalendar = nullptr;
@@ -72,7 +73,7 @@ bool AlarmCalendar::initialiseCalendars()
     QDir dir;
     dir.mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
     QString displayCal = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + displayCalendarName;
-    AkonadiModel::instance();
+    DataModel::initialise();
     Preferences::setBackend(Preferences::Akonadi);
     Preferences::self()->save();
     mResourcesCalendar = new AlarmCalendar();
@@ -123,11 +124,17 @@ AlarmCalendar::AlarmCalendar()
     , mEventType(CalEvent::EMPTY)
 {
     Resources* resources = Resources::instance();
+    connect(resources, &Resources::resourceAdded, this, &AlarmCalendar::slotResourceAdded);
     connect(resources, &Resources::eventsAdded, this, &AlarmCalendar::slotEventsAdded);
     connect(resources, &Resources::eventsToBeRemoved, this, &AlarmCalendar::slotEventsToBeRemoved);
     connect(resources, &Resources::eventUpdated, this, &AlarmCalendar::slotEventUpdated);
     connect(resources, &Resources::resourcesPopulated, this, &AlarmCalendar::slotResourcesPopulated);
     connect(resources, &Resources::settingsChanged, this, &AlarmCalendar::slotResourceSettingsChanged);
+
+    // Fetch events from all resources which already exist.
+    QVector<Resource> allResources = Resources::enabledResources();
+    for (Resource& resource : allResources)
+        slotResourceAdded(resource);
 }
 
 /******************************************************************************
@@ -192,7 +199,11 @@ bool AlarmCalendar::open()
 
         // Check for file's existence, assuming that it does exist when uncertain,
         // to avoid overwriting it.
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto statJob = KIO::stat(mUrl, KIO::StatJob::SourceSide, 2);
+#else
+        auto statJob = KIO::statDetails(mUrl, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
+#endif
         KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
         if (!statJob->exec() ||  load() == 0)
         {
@@ -405,7 +416,7 @@ void AlarmCalendar::updateDisplayKAEvents()
     if (mCalType == RESOURCES)
         return;
     qCDebug(KALARM_LOG) << "AlarmCalendar::updateDisplayKAEvents";
-    const Collection::Id key = DISPLAY_COL_ID;
+    const ResourceId key = DISPLAY_COL_ID;
     KAEvent::List& events = mResourceMap[key];
     for (KAEvent* event : events)
     {
@@ -431,7 +442,7 @@ void AlarmCalendar::updateDisplayKAEvents()
             delete event;
             continue;    // ignore events without usable alarms
         }
-        event->setCollectionId(key);
+        event->setResourceId(key);
         events += event;
         mEventMap[EventId(key, kcalevent->uid())] = event;
     }
@@ -444,7 +455,7 @@ void AlarmCalendar::updateDisplayKAEvents()
 * Called after the calendar is deleted or alarm types have been disabled, or
 * the AlarmCalendar is closed.
 */
-void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::Types types)
+void AlarmCalendar::removeKAEvents(ResourceId key, bool closing, CalEvent::Types types)
 {
     bool removed = false;
     ResourceMap::Iterator rit = mResourceMap.find(key);
@@ -455,11 +466,11 @@ void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::T
         for (int i = 0, end = events.count();  i < end;  ++i)
         {
             KAEvent* event = events[i];
-            bool remove = (event->collectionId() != key);
+            bool remove = (event->resourceId() != key);
             if (remove)
             {
                 if (key != DISPLAY_COL_ID)
-                    qCCritical(KALARM_LOG) << "AlarmCalendar::removeKAEvents: Event" << event->id() << ", resource" << event->collectionId() << "Indexed under resource" << key;
+                    qCCritical(KALARM_LOG) << "AlarmCalendar::removeKAEvents: Event" << event->id() << ", resource" << event->resourceId() << "Indexed under resource" << key;
             }
             else
                 remove = event->category() & types;
@@ -501,12 +512,12 @@ void AlarmCalendar::slotResourceSettingsChanged(Resource& resource, ResourceType
         if (resource.isValid())
         {
             // For each alarm type which has been disabled, remove the
-            // collection's events from the map, but not from the resource.
+            // resource's events from the map, but not from the resource.
             const CalEvent::Types enabled = resource.enabledTypes();
             const CalEvent::Types disabled = ~enabled & (CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
             removeKAEvents(resource.id(), false, disabled);
 
-            // For each alarm type which has been enabled, add the collection's
+            // For each alarm type which has been enabled, add the resource's
             // events to the map.
             if (enabled != CalEvent::EMPTY)
                 slotEventsAdded(resource, resource.events());
@@ -525,6 +536,16 @@ void AlarmCalendar::slotResourcesPopulated()
     mIgnoreAtLogin = true;
 }
 
+/******************************************************************************
+* Called when a resource has been added.
+* Add its KAEvent instances to those held by AlarmCalendar.
+* All events must have their resource ID set.
+*/
+void AlarmCalendar::slotResourceAdded(Resource& resource)
+{
+    slotEventsAdded(resource, resource.events());
+}
+
 /******************************************************************************
 * Called when events have been added to a resource.
 * Add corresponding KAEvent instances to those held by AlarmCalendar.
@@ -689,7 +710,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Resource* resourceptr)
                     default:
                         continue;
                 }
-                res = Resources::destination<AkonadiModel>(type);
+                res = Resources::destination(type);
             }
 
             Event::Ptr newev(new Event(*event));
@@ -747,8 +768,11 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
     FileStorage::Ptr calStorage(new FileStorage(calendar, file));
     if (append  &&  !calStorage->load())
     {
-        KIO::UDSEntry uds;
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 2);
+#else
+        auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatDetail::StatDefaultDetails);
+#endif
         KJobWidgets::setWindow(statJob, parent);
         statJob->exec();
         KFileItem fi(statJob->statResult(), url);
@@ -846,7 +870,7 @@ bool AlarmCalendar::endUpdate()
 
 /******************************************************************************
 * Save the calendar, or flag it for saving if in a group of calendar update calls.
-* Note that this method has no effect for Akonadi calendars.
+* Note that this method has no effect for resources calendars.
 */
 bool AlarmCalendar::save()
 {
@@ -899,7 +923,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
     // Check that the event type is valid for the calendar
     Resource nullresource;
     Resource& resource(resourceptr ? *resourceptr : nullresource);
-    qCDebug(KALARM_LOG) << "AlarmCalendar::addEvent:" << evnt.id() << ", resource" << resource.id();
+    qCDebug(KALARM_LOG) << "AlarmCalendar::addEvent:" << evnt.id() << ", resource" << resource.displayId();
     const CalEvent::Type type = evnt.category();
     if (type != mEventType)
     {
@@ -917,7 +941,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
         }
     }
 
-    Collection::Id key = resource.id();
+    ResourceId key = resource.id();
     Event::Ptr kcalEvent((mCalType == RESOURCES) ? (Event*)nullptr : new Event);
     KAEvent* event = new KAEvent(evnt);
     QString id = event->id();
@@ -948,7 +972,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
             res = resource;
         else
         {
-            res = Resources::destination<AkonadiModel>(type, promptParent, noPrompt, cancelled);
+            res = Resources::destination(type, promptParent, noPrompt, cancelled);
             if (!res.isValid())
             {
                 const char* typeStr = (type == CalEvent::ACTIVE) ? "Active alarm" : (type == CalEvent::ARCHIVED) ? "Archived alarm" : "alarm Template";
@@ -958,7 +982,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
         if (res.isValid())
         {
             // Don't add event to mEventMap yet - its Akonadi item id is not yet known.
-            // It will be added once it is inserted into AkonadiModel.
+            // It will be added once it is inserted into AkonadiDataModel.
             ok = res.addEvent(*event);
             remove = ok;   // if success, delete the local event instance on exit
             if (ok  &&  type == CalEvent::ACTIVE  &&  !event->enabled())
@@ -1008,8 +1032,8 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
 */
 void AlarmCalendar::addNewEvent(const Resource& resource, KAEvent* event, bool replace)
 {
-    const Collection::Id key = resource.id();
-    event->setCollectionId(key);
+    const ResourceId key = resource.id();
+    event->setResourceId(key);
     if (!replace)
     {
         mResourceMap[key] += event;
@@ -1046,7 +1070,7 @@ void AlarmCalendar::addNewEvent(const Resource& resource, KAEvent* event, bool r
 */
 bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
 {
-    const EventId newId(oldEventId.collectionId(), newEvent.id());
+    const EventId newId(oldEventId.resourceId(), newEvent.id());
     qCDebug(KALARM_LOG) << "AlarmCalendar::modifyEvent:" << oldEventId << "->" << newId;
     bool noNewId = newId.isEmpty();
     if (!noNewId  &&  oldEventId == newId)
@@ -1058,8 +1082,7 @@ bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
         return false;
     if (mCalType == RESOURCES)
     {
-        // Set the event's ID and Akonadi ID, and update the old
-        // event in Akonadi.
+        // Set the event's ID, and update the old event in the resources calendar.
         const KAEvent* storedEvent = event(oldEventId);
         if (!storedEvent)
         {
@@ -1068,7 +1091,7 @@ bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
         }
         if (noNewId)
             newEvent.setEventId(CalFormat::createUniqueId());
-        Resource resource = Resources::resource(oldEventId.collectionId());
+        Resource resource = Resources::resource(oldEventId.resourceId());
         if (!resource.isValid())
             return false;
         // Don't add new event to mEventMap yet - its Akonadi item id is not yet known
@@ -1167,27 +1190,27 @@ bool AlarmCalendar::deleteDisplayEvent(const QString& eventID, bool saveit)
 *         resource or local calendar
 *       = CalEvent::EMPTY otherwise.
 */
-CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, bool deleteFromAkonadi)
+CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, bool deleteFromResources)
 {
-    Resource resource = Resources::resource(event.collectionId());
+    Resource resource = Resources::resource(event.resourceId());
     if (!resource.isValid())
         return CalEvent::EMPTY;
-    return deleteEventInternal(event.id(), event, resource, deleteFromAkonadi);
+    return deleteEventInternal(event.id(), event, resource, deleteFromResources);
 }
 
-CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, Resource& resource, bool deleteFromAkonadi)
+CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, Resource& resource, bool deleteFromResources)
 {
     if (!resource.isValid())
         return CalEvent::EMPTY;
-    if (event.collectionId() != resource.id())
+    if (event.resourceId() != resource.id())
     {
-        qCCritical(KALARM_LOG) << "AlarmCalendar::deleteEventInternal: Event" << event.id() << ": resource" << event.collectionId() << "differs from 'resource'" << resource.id();
+        qCCritical(KALARM_LOG) << "AlarmCalendar::deleteEventInternal: Event" << event.id() << ": resource" << event.resourceId() << "differs from 'resource'" << resource.id();
         return CalEvent::EMPTY;
     }
-    return deleteEventInternal(event.id(), event, resource, deleteFromAkonadi);
+    return deleteEventInternal(event.id(), event, resource, deleteFromResources);
 }
 
-CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const KAEvent& event, Resource& resource, bool deleteFromAkonadi)
+CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const KAEvent& event, Resource& resource, bool deleteFromResources)
 {
     // Make a copy of the KAEvent and the ID QString, since the supplied
     // references might be destructed when the event is deleted below.
@@ -1196,8 +1219,8 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
 
     Event::Ptr kcalEvent;
     if (mCalendarStorage)
-        kcalEvent = mCalendarStorage->calendar()->event(id);
-    const Collection::Id key = resource.id();
+        kcalEvent = mCalendarStorage->calendar()->event(id);   // display calendar
+    const ResourceId key = resource.id();
     KAEventMap::Iterator it = mEventMap.find(EventId(key, id));
     if (it != mEventMap.end())
     {
@@ -1226,12 +1249,13 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
     CalEvent::Type status = CalEvent::EMPTY;
     if (kcalEvent)
     {
+        // It's a display calendar event
         status = CalEvent::status(kcalEvent);
         mCalendarStorage->calendar()->deleteEvent(kcalEvent);
     }
-    else if (deleteFromAkonadi)
+    else if (deleteFromResources)
     {
-        // It's an Akonadi event
+        // Delete from the resources calendar
         CalEvent::Type s = paramEvent.category();
         if (resource.deleteEvent(paramEvent))
             status = s;
@@ -1250,7 +1274,7 @@ KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool findUniqueId)
     if (!isValid())
         return nullptr;
     const QString eventId = uniqueID.eventId();
-    if (uniqueID.collectionId() == -1  &&  findUniqueId)
+    if (uniqueID.resourceId() == -1  &&  findUniqueId)
     {
         // The resource isn't known, but use the event ID if it is unique among
         // all resources.
@@ -1272,7 +1296,7 @@ KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool findUniqueId)
 
 /******************************************************************************
 * Return the event with the specified ID.
-* For the Akonadi version, this method is for the display calendar only.
+* This method is for the display calendar only.
 */
 Event::Ptr AlarmCalendar::kcalEvent(const QString& uniqueID)
 {
@@ -1309,7 +1333,7 @@ KAEvent::List AlarmCalendar::events(const QString& uniqueId) const
     {
         for (ResourceMap::ConstIterator rit = mResourceMap.constBegin();  rit != mResourceMap.constEnd();  ++rit)
         {
-            const Collection::Id id = rit.key();
+            const ResourceId id = rit.key();
             KAEventMap::ConstIterator it = mEventMap.constFind(EventId(id, uniqueId));
             if (it != mEventMap.constEnd())
                 list += it.value();
@@ -1329,7 +1353,7 @@ KAEvent::List AlarmCalendar::events(const Resource& resource, CalEvent::Types ty
         return list;
     if (resource.isValid())
     {
-        const Collection::Id key = resource.id();
+        const ResourceId key = resource.id();
         ResourceMap::ConstIterator rit = mResourceMap.constFind(key);
         if (rit == mResourceMap.constEnd())
             return list;
@@ -1360,7 +1384,7 @@ KAEvent::List AlarmCalendar::events(const Resource& resource, CalEvent::Types ty
 
 /******************************************************************************
 * Return all events in the calendar which contain usable alarms.
-* For the Akonadi version, this method is for the display calendar only.
+* This method is for the display calendar only.
 * Optionally the event type can be filtered, using an OR of event types.
 */
 Event::List AlarmCalendar::kcalEvents(CalEvent::Type type)
@@ -1465,7 +1489,7 @@ void AlarmCalendar::findEarliestAlarm(const Resource& resource)
     findEarliestAlarm(resource.id());
 }
 
-void AlarmCalendar::findEarliestAlarm(Akonadi::Collection::Id key)
+void AlarmCalendar::findEarliestAlarm(ResourceId key)
 {
     EarliestMap::Iterator eit = mEarliestAlarm.find(key);
     if (eit != mEarliestAlarm.end())
