@@ -25,8 +25,8 @@
 #include "kamail.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/identities.h>
-#include <kpimtextedit/texttospeech.h>
+#include <KAlarmCal/Identities>
+#include <KPIMTextEdit/TextToSpeech>
 #include <KLocalizedString>
 
 #include <QCommandLineParser>
@@ -215,8 +215,6 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
         else
             mParser->addOption(*(mOptions.at(i)));
     }
-    mParser->addVersionOption();
-    mParser->addHelpOption();
     mParser->addPositionalArgument(QStringLiteral("message"),
                                    i18n("Message text to display"),
                                    QStringLiteral("[message]"));
