@@ -21,41 +21,41 @@
 #include "editdlgtypes.h"
 #include "editdlg_p.h"
 
-#include "autoqpointer.h"
-#include "buttongroup.h"
-#include "checkbox.h"
-#include "colourbutton.h"
 #include "emailidcombo.h"
 #include "fontcolourbutton.h"
-#include "functions.h"
 #include "kalarmapp.h"
 #include "kamail.h"
 #include "latecancel.h"
-#include "lineedit.h"
 #include "mainwindow.h"
-#include "messagebox.h"
 #include "messagewin.h"
 #include "pickfileradio.h"
 #include "preferences.h"
-#include "radiobutton.h"
 #include "reminder.h"
-#include "shellprocess.h"
 #include "soundpicker.h"
 #include "sounddlg.h"
 #include "specialactions.h"
 #include "templatepickdlg.h"
-#include "timespinbox.h"
+#include "lib/autoqpointer.h"
+#include "lib/buttongroup.h"
+#include "lib/checkbox.h"
+#include "lib/colourbutton.h"
+#include "lib/file.h"
+#include "lib/lineedit.h"
+#include "lib/messagebox.h"
+#include "lib/radiobutton.h"
+#include "lib/shellprocess.h"
+#include "lib/timespinbox.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/identities.h>
+#include <KAlarmCal/Identities>
 
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <KCalendarCore/Person>
-#include <KCalUtils/kcalutils/icaldrag.h>
+#include <KCalUtils/ICalDrag>
 using namespace KCalendarCore;
 
 #include <KLocalizedString>
-#include <kfileitem.h>
+#include <KFileItem>
 
 #include <QComboBox>
 #include <QLabel>
@@ -83,8 +83,8 @@ class PickLogFileRadio : public PickFileRadio
             : PickFileRadio(b, e, text, group, parent) { }
         bool pickFile(QString& file) override    // called when browse button is pressed to select a log file
         {
-            return KAlarm::browseFile(file, i18nc("@title:window", "Choose Log File"), mDefaultDir, fileEdit()->text(), QString(),
-                                      false, parentWidget());
+            return File::browseFile(file, i18nc("@title:window", "Choose Log File"), mDefaultDir, fileEdit()->text(), QString(),
+                                    false, parentWidget());
         }
     private:
         QString mDefaultDir;   // default directory for log file browse button
@@ -338,7 +338,7 @@ void EditDisplayAlarmDlg::type_initValues(const KAEvent* event)
         reminder()->enableOnceOnly(isTimedRecurrence());   // must be called after mRecurrenceEdit is set up
         if (mSpecialActionsButton)
         {
-            KAEvent::ExtraActionOptions opts(nullptr);
+            KAEvent::ExtraActionOptions opts({});
             if (Preferences::defaultExecPreActionOnDeferral())
                 opts |= KAEvent::ExecPreActOnDeferral;
             if (Preferences::defaultCancelOnPreActionError())
@@ -640,12 +640,12 @@ void EditDisplayAlarmDlg::slotPickFile()
 {
     static QString defaultDir;   // default directory for file browse button
     QString file;
-    if (KAlarm::browseFile(file, i18nc("@title:window", "Choose Text or Image File to Display"),
-                                      defaultDir, mFileMessageEdit->text(), QString(), true, this))
+    if (File::browseFile(file, i18nc("@title:window", "Choose Text or Image File to Display"),
+                         defaultDir, mFileMessageEdit->text(), QString(), true, this))
     {
         if (!file.isEmpty())
         {
-            mFileMessageEdit->setText(KAlarm::pathOrUrl(file));
+            mFileMessageEdit->setText(File::pathOrUrl(file));
             contentsChanged();
         }
     }
@@ -676,31 +676,31 @@ bool EditDisplayAlarmDlg::checkText(QString& result, bool showErrorMessage) cons
 
         case tFILE:
         {
-            QString alarmtext = mFileMessageEdit->text().trimmed();
+            QString fileName = mFileMessageEdit->text().trimmed();
             QUrl url;
-            KAlarm::FileErr err = KAlarm::checkFileExists(alarmtext, url);
-            if (err == KAlarm::FileErr_None)
+            File::FileErr err = File::checkFileExists(fileName, url, MainWindow::mainMainWindow());
+            if (err == File::FileErr::None)
             {
                 KFileItem fi(url);
-                switch (KAlarm::fileType(fi.currentMimeType()))
+                switch (File::fileType(fi.currentMimeType()))
                 {
-                    case KAlarm::TextFormatted:
-                    case KAlarm::TextPlain:
-                    case KAlarm::TextApplication:
-                    case KAlarm::Image:
+                    case File::TextFormatted:
+                    case File::TextPlain:
+                    case File::TextApplication:
+                    case File::Image:
                         break;
                     default:
-                        err = KAlarm::FileErr_NotTextImage;
+                        err = File::FileErr::NotTextImage;
                         break;
                 }
             }
-            if (err != KAlarm::FileErr_None  &&  showErrorMessage)
+            if (err != File::FileErr::None  &&  showErrorMessage)
             {
                 mFileMessageEdit->setFocus();
-                if (!KAlarm::showFileErrMessage(alarmtext, err, KAlarm::FileErr_BlankDisplay, const_cast<EditDisplayAlarmDlg*>(this)))
+                if (!File::showFileErrMessage(fileName, err, File::FileErr::BlankDisplay, const_cast<EditDisplayAlarmDlg*>(this)))
                     return false;
             }
-            result = alarmtext;
+            result = fileName;
             break;
         }
         case tCOMMAND:
@@ -1436,8 +1436,8 @@ void EditEmailAlarmDlg::openAddressBook()
 void EditEmailAlarmDlg::slotAddAttachment()
 {
     QString file;
-    if (KAlarm::browseFile(file, i18nc("@title:window", "Choose File to Attach"),
-                           mAttachDefaultDir, QString(), QString(), true, this))
+    if (File::browseFile(file, i18nc("@title:window", "Choose File to Attach"),
+                         mAttachDefaultDir, QString(), QString(), true, this))
     {
         if (!file.isEmpty())
         {
@@ -1769,13 +1769,13 @@ bool CommandEdit::isScript() const
 */
 void CommandEdit::setText(const AlarmText& alarmText)
 {
-    QString text = alarmText.displayText();
-    bool script = alarmText.isScript();
+    const QString text = alarmText.displayText();
+    const bool script = alarmText.isScript();
     mTypeScript->setChecked(script);
     if (script)
         mScriptEdit->setPlainText(text);
     else
-        mCommandEdit->setText(KAlarm::pathOrUrl(text));
+        mCommandEdit->setText(File::pathOrUrl(text));
 }
 
 /******************************************************************************
