@@ -21,7 +21,7 @@
 #ifndef PREFDLG_H
 #define PREFDLG_H
 
-#include <kpagedialog.h>
+#include <KPageDialog>
 
 class EditPrefTab;
 class EmailPrefTab;
@@ -72,7 +72,7 @@ class KAlarmPrefDlg : public KPageDialog
 
         static KAlarmPrefDlg* mInstance;
         StackedScrollGroup*   mTabScrollGroup;
-        bool                  mShown{false};
+        bool                  mShown {false};
         bool                  mValid;
 };
 
