@@ -1,7 +1,7 @@
 /*
  *  resource.cpp  -  generic class containing an alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -61,6 +61,11 @@ bool Resource::isValid() const
     return mResource.isNull() ? false : mResource->isValid();
 }
 
+bool Resource::failed() const
+{
+    return mResource.isNull() ? true : mResource->failed();
+}
+
 #if 0
 ResourceType::Ptr Resource::resource() const
 {
@@ -73,6 +78,11 @@ ResourceId Resource::id() const
     return mResource.isNull() ? -1 : mResource->id();
 }
 
+ResourceId Resource::displayId() const
+{
+    return mResource.isNull() ? -1 : mResource->displayId();
+}
+
 Resource::StorageType Resource::storageType() const
 {
     return mResource.isNull() ? NoStorage : static_cast<StorageType>(mResource->storageType());
@@ -83,6 +93,11 @@ QString Resource::storageTypeString(bool description) const
     return mResource.isNull() ? QString() : mResource->storageTypeString(description);
 }
 
+QString Resource::storageTypeString(ResourceType::StorageType type)
+{
+    return ResourceType::storageTypeString(type);
+}
+
 QUrl Resource::location() const
 {
     return mResource.isNull() ? QUrl() : mResource->location();
@@ -194,14 +209,24 @@ void Resource::configSetStandard(CalEvent::Types types)
         mResource->configSetStandard(types);
 }
 
+bool Resource::isCompatible() const
+{
+    return mResource.isNull() ? false : mResource->isCompatible();
+}
+
 KACalendar::Compat Resource::compatibility() const
 {
     return mResource.isNull() ? KACalendar::Incompatible : mResource->compatibility();
 }
 
-bool Resource::isCompatible() const
+KACalendar::Compat Resource::compatibilityVersion(QString& versionString) const
 {
-    return mResource.isNull() ? false : mResource->isCompatible();
+    if (mResource.isNull())
+    {
+        versionString.clear();
+        return KACalendar::Incompatible;
+    }
+    return mResource->compatibilityVersion(versionString);
 }
 
 void Resource::editResource(QWidget* dialogParent)
@@ -220,6 +245,11 @@ bool Resource::load(bool readThroughCache)
     return mResource.isNull() ? false : mResource->load(readThroughCache);
 }
 
+bool Resource::reload()
+{
+    return mResource.isNull() ? false : mResource->reload();
+}
+
 bool Resource::isPopulated() const
 {
     return mResource.isNull() ? false : mResource->isPopulated();
@@ -235,6 +265,12 @@ bool Resource::isSaving() const
     return mResource.isNull() ? false : mResource->isSaving();
 }
 
+void Resource::close()
+{
+    if (!mResource.isNull())
+        mResource->close();
+}
+
 QList<KAEvent> Resource::events() const
 {
     return mResource.isNull() ? QList<KAEvent>() : mResource->events();
