@@ -1,7 +1,7 @@
 /*
  *  resourcetype.cpp  -  base class for an alarm calendar resource type
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,6 +37,16 @@ ResourceType::~ResourceType()
 {
 }
 
+bool ResourceType::failed() const
+{
+    return mFailed  ||  !isValid();
+}
+
+ResourceId ResourceType::displayId() const
+{
+    return id();
+}
+
 bool ResourceType::isEnabled(CalEvent::Type type) const
 {
     return (type == CalEvent::EMPTY) ? enabledTypes() : enabledTypes() & type;
@@ -58,32 +68,28 @@ QColor ResourceType::foregroundColour(CalEvent::Types types) const
     else
         types &= alarmTypes();
 
-//TODO: Should this look for the first writable alarm type?
+    // Find the highest priority alarm type.
+    // Note that resources currently only contain a single alarm type.
     CalEvent::Type type;
+    QColor colour;        // default to invalid colour
     if (types & CalEvent::ACTIVE)
-        type = CalEvent::ACTIVE;
+    {
+        type   = CalEvent::ACTIVE;
+        colour = KColorScheme(QPalette::Active).foreground(KColorScheme::NormalText).color();
+    }
     else if (types & CalEvent::ARCHIVED)
-        type = CalEvent::ARCHIVED;
+    {
+        type   = CalEvent::ARCHIVED;
+        colour = Preferences::archivedColour();
+    }
     else if (types & CalEvent::TEMPLATE)
-        type = CalEvent::TEMPLATE;
+    {
+        type   = CalEvent::TEMPLATE;
+        colour = KColorScheme(QPalette::Active).foreground(KColorScheme::LinkText).color();
+    }
     else
         type = CalEvent::EMPTY;
 
-    QColor colour;
-    switch (type)
-    {
-        case CalEvent::ACTIVE:
-            colour = KColorScheme(QPalette::Active).foreground(KColorScheme::NormalText).color();
-            break;
-        case CalEvent::ARCHIVED:
-            colour = Preferences::archivedColour();
-            break;
-        case CalEvent::TEMPLATE:
-            colour = KColorScheme(QPalette::Active).foreground(KColorScheme::LinkText).color();
-            break;
-        default:
-            break;
-    }
     if (colour.isValid()  &&  !isWritable(type))
         return KColorUtils::lighten(colour, 0.2);
     return colour;
@@ -94,6 +100,12 @@ bool ResourceType::isCompatible() const
     return compatibility() == KACalendar::Current;
 }
 
+KACalendar::Compat ResourceType::compatibility() const
+{
+    QString versionString;
+    return compatibilityVersion(versionString);
+}
+
 /******************************************************************************
 * Return all events belonging to this resource, for enabled alarm types.
 */
@@ -167,6 +179,7 @@ void ResourceType::removeResource(ResourceId id)
 */
 void ResourceType::setLoadedEvents(QHash<QString, KAEvent>& newEvents)
 {
+    qCDebug(KALARM_LOG) << "ResourceType::setLoadedEvents: count" << newEvents.count();
     const CalEvent::Types types = enabledTypes();
 
     // Replace existing events with the new ones, and find events which no
@@ -219,10 +232,11 @@ void ResourceType::setLoadedEvents(QHash<QString, KAEvent>& newEvents)
 * To be called when events have been created or updated, to amend them in the
 * resource's list.
 */
-void ResourceType::setUpdatedEvents(const QList<KAEvent>& events)
+void ResourceType::setUpdatedEvents(const QList<KAEvent>& events, bool notify)
 {
     const CalEvent::Types types = enabledTypes();
-    QList<KAEvent> eventsAdded;
+    mEventsAdded.clear();
+    mEventsUpdated.clear();
     for (const KAEvent& event : events)
     {
         auto it = mEvents.find(event.id());
@@ -230,7 +244,7 @@ void ResourceType::setUpdatedEvents(const QList<KAEvent>& events)
         {
             mEvents[event.id()] = event;
             if (event.category() & types)
-                eventsAdded += event;
+                mEventsAdded += event;
         }
         else
         {
@@ -238,11 +252,31 @@ void ResourceType::setUpdatedEvents(const QList<KAEvent>& events)
             bool changed = !ev.compare(event, KAEvent::Compare::Id | KAEvent::Compare::CurrentState);
             ev = event;   // update existing event
             if (changed  &&  (event.category() & types))
-                Resources::notifyEventUpdated(this, event);
+            {
+                if (notify)
+                    Resources::notifyEventUpdated(this, event);
+                else
+                    mEventsUpdated += event;
+            }
         }
     }
-    if (!eventsAdded.isEmpty())
-        Resources::notifyEventsAdded(this, eventsAdded);
+    if (notify  &&  !mEventsAdded.isEmpty())
+        Resources::notifyEventsAdded(this, mEventsAdded);
+}
+
+/******************************************************************************
+* Notifies added and updated events, after setUpdatedEvents() was called with
+* notify = false.
+*/
+void ResourceType::notifyUpdatedEvents()
+{
+    for (const KAEvent& event : qAsConst(mEventsUpdated))
+        Resources::notifyEventUpdated(this, event);
+    mEventsUpdated.clear();
+
+    if (!mEventsAdded.isEmpty())
+        Resources::notifyEventsAdded(this, mEventsAdded);
+    mEventsAdded.clear();
 }
 
 /******************************************************************************
@@ -264,7 +298,8 @@ void ResourceType::setDeletedEvents(const QList<KAEvent>& events)
                 eventsToNotify += event;
         }
     }
-    Resources::notifyEventsToBeRemoved(this, eventsToNotify);
+    if (!eventsToNotify.isEmpty())
+        Resources::notifyEventsToBeRemoved(this, eventsToNotify);
     for (const QString& id : eventsToDelete)
         mEvents.remove(id);
 }
@@ -279,7 +314,24 @@ void ResourceType::setLoaded(bool loaded) const
     }
 }
 
-QString ResourceType::storageTypeStr(bool description, bool file, bool local) const
+void ResourceType::setFailed()
+{
+    mFailed = true;
+}
+
+QString ResourceType::storageTypeString(StorageType type)
+{
+    switch (type)
+    {
+        case File:
+        case Directory:
+            return storageTypeStr(true, (type == File), true);
+        default:
+            return QString();
+    }
+}
+
+QString ResourceType::storageTypeStr(bool description, bool file, bool local)
 {
     if (description)
         return file ? i18nc("@info", "KAlarm Calendar File") : i18nc("@info", "KAlarm Calendar Directory");
