@@ -22,12 +22,12 @@
 
 #include "alarmcalendar.h"
 #include "functions.h"
-#include "messagebox.h"
 #include "resources/resources.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/alarmtext.h>
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/AlarmText>
+#include <KAlarmCal/KAEvent>
 
 #include <KLocalizedString>
 
@@ -78,7 +78,7 @@ class UndoItem
         virtual void       dumpDebugTitle(const char* typeName) const;
 
         QString            mName;      // specified action name (overrides default)
-        int                mId{0};     // unique identifier (only for mType = UNDO, REDO)
+        int                mId {0};    // unique identifier (only for mType = UNDO, REDO)
         Undo::Type         mType;      // which list (if any) the object is in
         CalEvent::Type     mCalendar;
 };
